mod.service('$tabber', [
    '$rootScope',
    '$timeout',
    function ($rootScope, $timeout) {

        this.modifySubCellsLayout = function() {
            var _this = this;

            prism.on('dashboardloaded', function (ev, args) {

                // Updates sub-cells resize elements on dashboard edit mode enable action
                $rootScope.$watch(function() {
                    return args.dashboard.editing;
                }, function(newValue, oldValue) {
                    var isValueChanged = newValue !== oldValue;

                    if (isValueChanged && newValue) {
                        $timeout(function() {
                            _this._adjustSubCellsResizers();
                        }, 100);
                    }
                });
            });

            // Adjusts sub-cells to fit all width or row
            $rootScope.$on('tab-change', function(ev, args) {
                if (!args) return;

                _this._adjustSubCells();
                _this._adjustSubCellsResizers();
                _this._redrawVisibleWidgets();
            });
        };

        this._adjustSubCells = function () {
            $('.dashboard-layout-cell')
                .toArray()
                .forEach(function (cellElement) {
                    var visibleSubCells = $(cellElement).find('.dashboard-layout-subcell-host:not(.dontshowme-parent)');
                    var hiddenSubCells = $(cellElement).find('.dashboard-layout-subcell-host.dontshowme-parent');
                    var isRowWithHiddenCells = Boolean(hiddenSubCells.length);

                    if (visibleSubCells.length && isRowWithHiddenCells) {
                        visibleSubCells.css('width', (100 / visibleSubCells.length) + '%');
                    }

                    // Adjusts hidden sub-cells to prevent UI gaps during tab switching
                    if (isRowWithHiddenCells) {
                        hiddenSubCells.css('width', (100 / hiddenSubCells.length) + '%');
                    }
                });
        };

        this._adjustSubCellsResizers = function () {
            $('.dashboard-layout-cell')
                .toArray()
                .forEach(function (cellElement) {
                    var visibleSubCells = $(cellElement).find('.dashboard-layout-subcell-host:not(.dontshowme-parent)');
                    var hiddenSubCells = $(cellElement).find('.dashboard-layout-subcell-host.dontshowme-parent');
                    var isRowWithHiddenCells = Boolean(hiddenSubCells.length);

                    if (visibleSubCells.length && isRowWithHiddenCells) {
                        visibleSubCells
                            .find('.ui-resizable-handle')
                            .toArray()
                            .forEach(function(resizeElement) {
                                $(resizeElement)
                                    .clone(false)
                                    .css({ cursor: 'auto' })
                                    .insertAfter(resizeElement);
                                $(resizeElement).remove();
                            });
                    }
                });
        };

        this._redrawVisibleWidgets = function () {
            // Redrawing widgets for current opened tab (without tabber widget)
            $('.dashboard-layout-subcell-host:not(.dontshowme-parent)').each(function(index, el) {
                var widgetIdToRedraw = $(el).find('widget:not([subtype=WidgetsTabber])').attr('widgetid');
                if(widgetIdToRedraw) {
                    prism.activeDashboard.widgets.get(widgetIdToRedraw).redraw();
                }
            });
        };
    }
]);